@@ -82,9 +82,9 @@ class midgame_strategy {
 			pthread_testcancel();
 			int score = info.board->board_diff_score();
 			if (score > 0)
-				return 10000;
+				return MAX_SCORE-1;	// Required to store move for alphabeta
 			else if (score < 0)
-				return -10000;
+				return MIN_SCORE+1;	// Required to store move for alphabeta
 			return 0;
 		}
 		static void	log_position(int /*pos*/) {}
@@ -132,9 +132,9 @@ class midgame_strategy_with_random {
 			pthread_testcancel();
 			int score = info.board->board_diff_score()+get_random();
 			if (score > 0)
-				return 10000;
+				return MAX_SCORE-1;	// Required to store move for alphabeta
 			else if (score < 0)
-				return -10000;
+				return MIN_SCORE+1;	// Required to store move for alphabeta
 			return 0;
 		}
 		static void	log_position(int /*pos*/) {}
