@@ -1,6 +1,6 @@
 /*
 	gpref.cc	GRhino Gnome Frontend Preferences Dialog Box
-	Copyright (c) 2004, 2005 Kriang Lerdsuwanakij
+	Copyright (c) 2004, 2005, 2010 Kriang Lerdsuwanakij
 	email:		lerdsuwa@users.sourceforge.net
 
 	This program is free software; you can redistribute it and/or modify
@@ -201,7 +201,7 @@ void preferences_apply(GnomePropertyBox * /*propertybox*/, gint page, gpointer /
 	start_random_game_pieces = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(spin_start_pieces));
 
 	entry = gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo_opening)->entry));
-	if (entry != _(opening_name.c_str()) || old_animate_opening != animate_opening) {
+        if (entry != _(opening_name.c_str()) || old_animate_opening != animate_opening) {
 		for (int i = 0; i < get_num_opening(); ++i) {
 			if (entry == _(get_opening_name(i))) {
 				opening_name = get_opening_name(i);
@@ -209,16 +209,18 @@ void preferences_apply(GnomePropertyBox * /*propertybox*/, gint page, gpointer /
 				break;
 			}
 		} 
-		need_draw_board = true;
 
+		if (view_mode == VIEW_MODE_NONE) {
+		        need_draw_board = true;
 					// Check if all moves are AI's
-		int	i = cur_game_info.num_history;
+                        int	i = cur_game_info.num_history;
 
 					// Skip AI's turns
-		while (i > cur_game_info.min_num_history && is_computer_player(cur_game_info.player_history[i-2]))
-			i--;
-		if (i == cur_game_info.min_num_history)
-			need_new_game = true;
+                        while (i > cur_game_info.min_num_history && is_computer_player(cur_game_info.player_history[i-2]))
+			        i--;
+                        if (i == cur_game_info.min_num_history)
+			        need_new_game = true;
+                }
 	}
 
 			// Add/remove hints if necessary
@@ -301,7 +303,12 @@ void preferences_apply(GnomePropertyBox * /*propertybox*/, gint page, gpointer /
 		resize_board_widget();
 	}
 
-	if (need_new_game) {
+	if (view_mode) {
+		if (need_draw_board)
+			draw_board();
+		update_menu_and_toolbar_pref();
+	}
+	else if (need_new_game) {
 		new_game();
 					// This must come after need_load_theme
 					// so that dimensions are properly computed
