@@ -1,6 +1,6 @@
 /*
 	grhino.cc	GRhino Gnome Frontend
-	Copyright (c) 2000-2005, 2006 Kriang Lerdsuwanakij
+	Copyright (c) 2000-2005, 2006, 2010 Kriang Lerdsuwanakij
 	email:		lerdsuwa@users.sourceforge.net
 
 	This program is free software; you can redistribute it and/or modify
@@ -45,26 +45,45 @@
 #include <deque>
 #include <vector>
 
+const
 #include "black.xpm"
+const
 #include "white.xpm"
+const
 #include "empty.xpm"
+const
 #include "hint_black.xpm"
+const
 #include "hint_white.xpm"
+const
 #include "black_last.xpm"
+const
 #include "white_last.xpm"
+const
 #include "highlight_black.xpm"
+const
 #include "highlight_white.xpm"
+const
 #include "highlight_empty.xpm"
 
+const
 #include "top.xpm"
+const
 #include "bottom.xpm"
+const
 #include "left.xpm"
+const
 #include "right.xpm"
 
+const
 #include "icon_new.xpm"
+const
 #include "icon_empty.xpm"
+const
 #include "icon_black.xpm"
+const
 #include "icon_white.xpm"
+const
 #include "icon_bw.xpm"
 
 #include "board.h"
@@ -87,7 +106,7 @@
 
 // Grab version number in VERSION variable
 #undef VERSION
-char *
+const char *
 #include "scripts/version"
 ;
 
@@ -1088,6 +1107,8 @@ void finish_edit_mode()
 
 	cancel_edit_mode();
 
+	eval_new_game();
+
 	new_game(cur_game_info, *view_board_ptr, view_player);
 
 	draw_board();
@@ -1300,59 +1321,43 @@ bool edit_toolbar_docked = false;
 
 void update_toolbar()
 {
+        if (show_toolbar && !main_toolbar_docked) {
+	        gnome_app_add_toolbar(GNOME_APP(main_window),
+		  	              GTK_TOOLBAR(main_toolbar),
+                                      "main_toolbar",
+                                      BONOBO_DOCK_ITEM_BEH_EXCLUSIVE,
+                                      BONOBO_DOCK_TOP,
+                                      1, 0, 0);
+                main_toolbar_docked = true;
+        }
 	if (main_toolbar_docked) {
+  		BonoboDockItem *dock_item = gnome_app_get_dock_item_by_name(GNOME_APP(main_window),
+									            "main_toolbar");
+                if (show_toolbar)
+			gtk_widget_show(GTK_WIDGET(dock_item));
+                else
+		        gtk_widget_hide(GTK_WIDGET(dock_item));
+        }
+
+	if (view_mode == VIEW_MODE_EDIT && !edit_toolbar_docked) {
+		gnome_app_add_toolbar(GNOME_APP(main_window),
+				      GTK_TOOLBAR(edit_toolbar),
+				      "edit_toolbar",
+				      BONOBO_DOCK_ITEM_BEH_EXCLUSIVE,
+				      BONOBO_DOCK_TOP,
+				      2, 0, 0);
+		edit_toolbar_docked = true;
+	}
+	if (edit_toolbar_docked) {
 		BonoboDockItem *dock_item = gnome_app_get_dock_item_by_name(GNOME_APP(main_window),
-									    "main_toolbar");
-		if (show_toolbar)
+								    "edit_toolbar");
+		if (view_mode == VIEW_MODE_EDIT)
 			gtk_widget_show(GTK_WIDGET(dock_item));
 		else
 			gtk_widget_hide(GTK_WIDGET(dock_item));
-
-		if (edit_toolbar_docked) {
-			dock_item = gnome_app_get_dock_item_by_name(GNOME_APP(main_window),
-								    "edit_toolbar");
-			if (show_toolbar && view_mode == VIEW_MODE_EDIT)
-				gtk_widget_show(GTK_WIDGET(dock_item));
-			else
-				gtk_widget_hide(GTK_WIDGET(dock_item));
-		}
-		else if (show_toolbar && view_mode == VIEW_MODE_EDIT) {
-			gnome_app_add_toolbar(GNOME_APP(main_window),
-					      GTK_TOOLBAR(edit_toolbar),
-					      "edit_toolbar",
-					      BONOBO_DOCK_ITEM_BEH_EXCLUSIVE,
-					      BONOBO_DOCK_TOP,
-					      2, 0, 0);
-			dock_item = gnome_app_get_dock_item_by_name(GNOME_APP(main_window),
-								    "edit_toolbar");
-			edit_toolbar_docked = true;
-			gtk_widget_show(GTK_WIDGET(dock_item));
-		}
-
-		gtk_window_resize(GTK_WINDOW(main_window), 1, 1);
 	}
-	else if (show_toolbar) {
-		gnome_app_add_toolbar(GNOME_APP(main_window),
-				      GTK_TOOLBAR(main_toolbar),
-				      "main_toolbar",
-				      BONOBO_DOCK_ITEM_BEH_EXCLUSIVE,
-				      BONOBO_DOCK_TOP,
-				      1, 0, 0);
-		main_toolbar_docked = true;
 
-		if (view_mode == VIEW_MODE_EDIT) {
-			gnome_app_add_toolbar(GNOME_APP(main_window),
-					      GTK_TOOLBAR(edit_toolbar),
-					      "edit_toolbar",
-					      BONOBO_DOCK_ITEM_BEH_EXCLUSIVE,
-					      BONOBO_DOCK_TOP,
-					      2, 0, 0);
-			edit_toolbar_docked = true;
-		}
-
-			// Recursive to show widget
-		update_toolbar();
-	}
+	gtk_window_resize(GTK_WINDOW(main_window), 1, 1);
 }
 
 /*************************************************************************
@@ -1491,7 +1496,7 @@ void menu_help_about(GtkWidget * /*widget*/, gpointer /*data*/)
 			translator = 0;
 
 		about_dialog = gnome_about_new(_(prog_name), prog_ver,
-					       _("(c) 2000-5, 2006 Kriang Lerdsuwanakij"),
+					       _("(c) 2000-7, 2010 Kriang Lerdsuwanakij"),
 					       _("A reversi program"),
 					       authors,
 					       documenters,
