@@ -1,6 +1,6 @@
 /*
 	gtp-rhino.cc	GRhino GTP Frontend
-	Copyright (c) 2005, 2006 Kriang Lerdsuwanakij
+	Copyright (c) 2005, 2006, 2010 Kriang Lerdsuwanakij
 	email:		lerdsuwa@users.sourceforge.net
 
 	This program is free software; you can redistribute it and/or modify
@@ -55,7 +55,7 @@
 
 // Grab version number in VERSION variable
 #undef VERSION
-char *
+const char *
 #include "scripts/version"
 ;
 
@@ -727,7 +727,7 @@ int	main_real(int argc, char *argv[])
 
 			if (arg == "-h" || arg == "--help") {
 				std::cout << prog_name << ' ' << prog_ver << _(" - GTP Frontend for Rhino\n");
-				std::cout << _("(c) 2005 Kriang Lerdsuwanakij\n\n");
+				std::cout << _("(c) 2005, 2006, 2010 Kriang Lerdsuwanakij\n\n");
 				gtout(std::cout, _("Usage:   %$ [options]\n")) << prog_name;
 				std::cout << _("Available options:\n");
 				std::cout << _("     -b N, --book=N    Use open book variation N.  Allowed = 0..5 (means None..Very high).\n");
